import http from './http.js'
import utils from '../utils/utils.js'


let limit = {}
let debounce = {}

const models = []

const config = {
	// 示例
	// wxLogin : {url : '/api/wxLogin', method : 'POST', 
	// auth : false, showLoading : true, loadingTitle : '加载中...',
	// limit : 1000
	// },

	getConfig: {
		url: '/api/getConfig',
		method: 'GET',
		limit: 500
	},


	//轮播图-轮播图列表
	queryBannerList: {
		url: '/workorder/banner/queryBannerList',
		method: 'GET',
	},


	//工单信息-查询工单列表
	queryTemplateList: {
		url: '/workorder/template/queryTemplateList',
		method: 'GET',
	},
	//公告信息-查询公告列表
	queryNewsList: {
		url: '/workorder/news/queryNewsList',
		method: 'GET',
	},
	// 公告信息-根据id查询公告信息
	queryNewsById: {
		url: '/workorder/news/queryNewsById',
		method: 'GET',
	},
	// 配置信息-帮助中心
	helpInfo: {
		url: '/workorder/config/helpInfo',
		method: 'GET',
	},
	// 配置信息-隐私协议
	privacyInfo: {
		url: '/workorder/config/privacyInfo',
		method: 'GET',
	},
	//用户列表
	queryUserList: {
		url: '/workorder/user/queryUserList',
		method: 'GET',
	},
	//工单信息-工序卡1(选配)详情
	queryStepOne: {
		url: '/workorder/template/queryStepOne',
		method: 'GET',
	},
	//工单信息-工序卡2详情
	queryStepTwo: {
		url: '/workorder/template/queryStepTwo',
		method: 'GET',
	},
	//收藏信息-我的收藏
	queryCollectionList: {
		url: '/workorder/collection/queryCollectionList',
		method: 'GET',
	},
	//工单信息-根据id查询工单详情
	queryTemplateById: {
		url: '/workorder/template/queryTemplateById',
		method: 'GET',
	},
	//工单信息-工序卡3详情
	queryStepThree: {
		url: '/workorder/template/queryStepThree',
		method: 'GET',
	},
	
}


export function api(key, data, callback, loadingTitle) {
	let req = config[key]

	if (!req) {
		console.error('无效key--------' + key);
		return
	}

	if (typeof callback == 'string') {
		loadingTitle = callback
	}

	if (typeof data == 'function') {
		callback = data
		data = {}
	}

	// 接口限流
	if (req.limit) {
		let storageKey = req.url
		let storage = limit[storageKey]
		if (storage && new Date().getTime() - storage < req.limit) {
			return
		}
		limit[storageKey] = new Date().getTime()
	}

	//必须登录
	if (req.auth) {
		if (!uni.getStorageSync('token')) {
			utils.toLogin()
			console.error('需要登录')
			return
		}
	}

	// 接口防抖
	if (req.debounce) {

		let storageKey = req.url
		let storage = debounce[storageKey]

		if (storage) {
			clearTimeout(storage)
		}

		debounce[storageKey] = setTimeout(() => {

			clearTimeout(storage)

			delete debounce[storageKey]

			http.http(req.url, data, callback, req.method,
				loadingTitle || req.showLoading, loadingTitle || req.loadingTitle)
		}, req.debounce)

		return
	}

	http.http(req.url, data, callback, req.method,
		loadingTitle || req.showLoading, loadingTitle || req.loadingTitle)
}



function addApiModel(model, key) {
	for (let k in model) {
		if (config[`${k}`]) {
			console.error(`重名api------model=${key},key=${k}`);
			continue
		}
		config[`${k}`] = model[k]
		// config[`${key}_${k}`] = model[k]
	}
}

models.forEach(key => {
	addApiModel(require(`./model/${key}.js`).default, key)
})

export default api